- x
An 'influence_stat'-class object.
- digits
The number of digits after the decimal.
Default is 3.
- what
A character vector of the
results #' to be printed, can be
one or more of the following:
"parameters", "fit_measures",
and "mahalanobis". Default
is c("parameters", "fit_measures", "mahalanobis").
- first
Numeric. If not NULL, it prints
only the first k cases, k equal to first.
Default is 10.
- sort_parameters_by
String.
If it is "est", the cases are sorted individually
on each columns. If it is "gcd",
the default,
then cases are sorted by generalized Cook's distance
or approximate generalized Cook's distance, depending on
which column is available.
If NULL, cases are not sorted.
- sort_fit_measures_by
String. Default is NULL and
the output of case influence on fit measures is not
sorted. If set to a column
names of case influence on fit measures , cases will
sorted by these columns.
The sorting is done on the absolute values
if sort_fit_measures_on_absolute is TRUE, and in decreasing
order if decreasing is TRUE. If decrease
is FALSE, the order is increasing. If sort_fit_measures_on_absolute
is FALSE, the sorting is done on the raw values.
- sort_mahalanobis
Logical. If TRUE, the default, the cases
in the output of Mahalanobis distance
will be sorted based on Mahalanobis distance.
The order is determined by sort_mahalanobis_decreasing.
- sort_fit_measures_decreasing
Logical. Whether cases, if sorted
on fit measures,
are on decreasing order in the output of
case influence on fit measures. Default is TRUE.
- sort_fit_measures_on_absolute
Logical. Whether
cases, if sorted on fit measures,
are sorted on absolute values of fit measures. Default is TRUE.
See sort_fit_measures_by.
- sort_mahalanobis_decreasing
Logical. Whether cases, if sorted
on Mahalanobis distance,
is on decreasing order. Default is TRUE.
- ...
Optional arguments. Passed to
other print methods, such as print.est_change(),
print.fit_measures_change(), and print.md_semfindr().